@@ -1,6 +1,7 @@
 class PyTerrierIntegration():
     def __init__(self, tira_client):
         self.tira_client = tira_client
+        self.irds_docker_image = 'webis/tira-application:0.0.36'
 
     def retriever(self, approach, dataset=None, verbose=False):
         from tira.pyterrier_util import TiraFullRankTransformer
@@ -30,7 +31,7 @@ class PyTerrierIntegration():
                  '-v', full_rank_data + ':/output/:rw',
                  '-v', truth_data + ':/truth/:rw',
                  '--entrypoint', '/irds_cli.sh',
-                 'webis/tira-application:0.0.36',
+                 self.irds_docker_image,
                  '--output_dataset_path', '/output',
                  '--ir_datasets_id', irds_dataset_id,
                  '--output_dataset_truth_path', '/truth'
@@ -38,6 +39,59 @@ class PyTerrierIntegration():
 
         return full_rank_data      
 
+    def create_rerank_file(self, run_df=None, run_file=None, irds_dataset_id=None):
+        from pathlib import Path
+        import tempfile
+        from tira.io_utils import run_cmd
+        import gzip
+        import json
+        from tira.third_party_integrations import persist_and_normalize_run
+
+        if run_df is None and run_file is None:
+            raise ValueError('Please pass either run_df or run_file')
+
+        if run_file is not None:
+            return run_file
+
+        run_file = tempfile.TemporaryDirectory('-rerank-run').name
+        Path(run_file).mkdir(parents=True, exist_ok=True)
+
+        if 'text' not in run_df.columns and 'body' not in run_df.columns:
+            if not irds_dataset_id:
+                raise ValueError(f'Please pass a irds_dataset_id. Got {irds_dataset_id}.')
+            persist_and_normalize_run(run_df, 'system-is-ignored', run_file)
+
+            cache_dir = self.tira_client.tira_cache_dir + '/pyterrier/' + irds_dataset_id
+            irds_cache = cache_dir + '/irds-cache/'
+
+            run_cmd(['docker', 'run',
+                     '-v', irds_cache + ':/root/.ir_datasets/:rw',
+                     '-v', run_file + ':/output/:rw',
+                     '--entrypoint', '/irds_cli.sh',
+                     self.irds_docker_image,
+                     '--output_dataset_path', '/output',
+                     '--ir_datasets_id', irds_dataset_id,
+                     '--rerank', '/output'
+            ])
+        else:
+            with gzip.open(run_file + '/rerank.jsonl.gz', 'wt') as f:
+                for _, i in run_df.iterrows():
+                    i = i.to_dict()
+
+                    for k in ['original_query', 'original_document']:
+                        if k not in i:
+                            i[k] = {}
+
+                    if 'text' not in i and 'body' in i:
+                        i['text'] = i['body']
+
+                    if 'text' not in i:
+                        raise ValueError(f'I expect a field "text", but only found fields {i.keys()}.')
+
+                    f.write(json.dumps(i) + '\n')
+
+        return run_file
+
     def from_submission(self, approach, dataset=None, datasets=None):
         software = self.tira_client.docker_software(approach)
         
@@ -75,7 +129,7 @@ class PyTerrierIntegration():
 
         return pt.Transformer.from_df(pd.concat(df_ret))
 
-    def reranker(self, approach):
+    def reranker(self, approach, irds_id=None):
         from tira.pyterrier_util import TiraLocalExecutionRerankingTransformer
-        return TiraLocalExecutionRerankingTransformer(approach, self.tira_client)
+        return TiraLocalExecutionRerankingTransformer(approach, self.tira_client, irds_id=irds_id)
 
